<?php $TRANSLATIONS = array(
"Information about vCard is incorrect. Please reload the page." => "Подаци о вКарти су неисправни. Поново учитајте страницу.",
"Contacts" => "Контакти",
"Download" => "Преузимање",
"Edit" => "Уреди",
"Delete" => "Обриши",
"Cancel" => "Откажи",
"This is not your addressbook." => "Ово није ваш адресар.",
"Contact could not be found." => "Контакт се не може наћи.",
"Work" => "Посао",
"Home" => "Кућа",
"Mobile" => "Мобилни",
"Text" => "Текст",
"Voice" => "Глас",
"Fax" => "Факс",
"Video" => "Видео",
"Pager" => "Пејџер",
"Birthday" => "Рођендан",
"Contact" => "Контакт",
"Add Contact" => "Додај контакт",
"Organization" => "Организација",
"Preferred" => "Пожељан",
"Phone" => "Телефон",
"Email" => "Е-маил",
"Address" => "Адреса",
"Download contact" => "Преузми контакт",
"Delete contact" => "Обриши контакт",
"Type" => "Тип",
"PO Box" => "Поштански број",
"Extended" => "Прошири",
"City" => "Град",
"Region" => "Регија",
"Zipcode" => "Зип код",
"Country" => "Земља",
"Addressbook" => "Адресар",
"Addressbooks" => "Адресар",
"New Address Book" => "Нови адресар",
"Save" => "Сними"
);
